@@ -20,6 +20,7 @@ from aiohasupervisor.models.addons import (
     Repository,
     StoreAddon,
     StoreAddonComplete,
+    StoreAddonInstall,
     StoreAddonUpdate,
     StoreAddRepository,
     StoreInfo,
@@ -99,6 +100,7 @@ from aiohasupervisor.models.network import (
     IPv4Config,
     IPv6,
     IPv6Config,
+    MulticastDnsMode,
     NetworkInfo,
     NetworkInterface,
     NetworkInterfaceConfig,
@@ -235,6 +237,7 @@ __all__ = [
     "MountUsage",
     "MountsInfo",
     "MountsOptions",
+    "MulticastDnsMode",
     "NFSMountRequest",
     "NFSMountResponse",
     "NetworkInfo",
@@ -258,6 +261,7 @@ __all__ = [
     "StoreAddRepository",
     "StoreAddon",
     "StoreAddonComplete",
+    "StoreAddonInstall",
     "StoreAddonUpdate",
     "StoreInfo",
     "Suggestion",
