@@ -57,6 +57,7 @@ class Capability(StrEnum):
     """
 
     BPF = "BPF"
+    CHECKPOINT_RESTORE = "CHECKPOINT_RESTORE"
     DAC_READ_SEARCH = "DAC_READ_SEARCH"
     IPC_LOCK = "IPC_LOCK"
     NET_ADMIN = "NET_ADMIN"
@@ -357,6 +358,14 @@ class StoreAddonUpdate(Request):
     """StoreAddonUpdate model."""
 
     backup: bool | None = None
+    background: bool | None = None
+
+
+@dataclass(frozen=True, slots=True)
+class StoreAddonInstall(Request):
+    """StoreAddonInstall model."""
+
+    background: bool | None = None
 
 
 @dataclass(frozen=True, slots=True)
