@@ -1,11 +1,25 @@
 """Models for supervisor component."""
 
 from dataclasses import dataclass
+from enum import StrEnum
 from ipaddress import IPv4Address
 
 from .base import ContainerStats, Options, Request, ResponseData
 from .root import LogLevel, UpdateChannel
 
+# --- ENUMS ----
+
+
+class DetectBlockingIO(StrEnum):
+    """DetectBlockingIO type."""
+
+    OFF = "off"
+    ON = "on"
+    ON_AT_STARTUP = "on_at_startup"
+
+
+# --- OBJECTS ----
+
 
 @dataclass(frozen=True, slots=True)
 class SupervisorInfo(ResponseData):
@@ -26,6 +40,7 @@ class SupervisorInfo(ResponseData):
     diagnostics: bool | None
     auto_update: bool
     country: str | None
+    detect_blocking_io: bool
 
 
 @dataclass(frozen=True, slots=True)
@@ -53,3 +68,5 @@ class SupervisorOptions(Options):
     content_trust: bool | None = None
     force_security: bool | None = None
     auto_update: bool | None = None
+    country: str | None = None
+    detect_blocking_io: DetectBlockingIO | None = None
